#
# spec file for package libsemigroups
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libsemigroups
%define lname	libsemigroups2
Version:        2.7.3
Release:        1.2
Summary:        Library with algorithms for computing finite and finitely presented semigroups
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://github.com/libsemigroups/libsemigroups
Source:         https://github.com/libsemigroups/libsemigroups/releases/download/v%version/%name-%version.tar.gz
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(fmt) >= 8.1.1

%description
A C++14 library containing implementations of several algorithms for
computing finite and finitely presented semigroups.

%package -n %lname
Summary:        Library with algorithms for computing finite and finitely presented semigroups
Group:          System/Libraries

%description -n %lname
A C++14 library containing implementations of several algorithms for
computing finite and finitely presented semigroups, namely:

	* the Froidure–Pin algorithm for computing finite semigroups
	* the Todd–Coxeter and Knuth–Bendix algorithms for finitely
	  presented semigroups and monoids;
	* the Schreier–Sims algorithm for permutation groups

%package devel
Summary:        Development files for the Semigroups library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
A C++14 library containing implementations of several algorithms for
computing finite and finitely presented semigroups, namely.

This subpackage provides the development headers for it.

%prep
%autosetup -p1

%build
autoreconf -fi
# hpcombi requires AVX-256, which is not guaranteed to exist everywhere
%configure --disable-static --disable-hpcombi \
	--enable-eigen --with-external-eigen \
	--enable-fmt --with-external-fmt
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%check
%make_build check

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libsemigroups.so.2*

%files devel
%_includedir/libsemigroups/
%_libdir/libsemigroups.so
%_libdir/pkgconfig/*.pc
%license LICENSE
%doc README.rst

%changelog
* Fri Jan 19 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.7.3
  * Optimise the Konieczny algorithm
* Thu Nov  2 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.7.2
  * Unspecified minor issues have been resolved.
* Wed Mar 29 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.7.1
  * present: fix sort_rules bug
* Wed Mar 22 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.7.0
  * Allow computation of strongly connected components of
    non-complete word graphs
* Mon Feb 27 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.6.2
  * Build system changes only
* Sun Feb 26 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.6.1
  * Remove auto return type from first_unused_letter
  * Properly initialise RepOrc
* Mon Feb  6 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.6.0
  * Add a second symmetric group presentation due to Moore
  * Add three functions to ``presentation`` namespace
  * Add presentation for the monoid of partial isometries of a
    cycle graph
  * word: implement user-defined literal ``_w`` for ``word_type``
  * New helper functions for `Presentation`
  * Add `congruence_kind` argument check to `ToddCoxeter` function
    `to_gap_string`
* Thu Dec 22 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.5.1
  * Minor release. No changelog provided.
* Thu Dec 15 2022 Dirk Müller <dmueller@suse.com>
- update to v2.5.0:
  * In this release a small number of issues are resolved, and
    one major new feature is added. The features added in this
    release are:
  * Add order_preserving_monoid presentation
  * Add presentations for the cyclic inverse monoid, and its order-
    preserving part
* Fri Dec  9 2022 Dirk Müller <dmueller@suse.com>
- update to v2.4.1:
  * This is a minor release fixing some issues in the build system that
    should have been included in the last release.
  * Change -march=avx -> -mavx by @james-d-mitchell in #418
* Thu Dec  1 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.4.0
  * Add replace_word presentation helper
  * A library of examples of finite presentations was added
- Delete pkgconfig.patch
* Sat Nov 19 2022 Jan Engelhardt <jengelh@inai.de>
- Enable fmt component
- Refresh pkgconfig.patch
* Sat Nov 19 2022 Jan Engelhardt <jengelh@inai.de>
- Add pkgconfig.patch
* Fri Oct 28 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.3.2
  * Fix inaccurate exception information for ``replace_subword``
  * string-view: fix bug in append method This bug sometimes
    caused the ``normal_form`` member function of the
    ``Kambites`` class template to return incorrect results, or
    sometimes to cause a crash.
* Tue Oct 11 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.3.1
  * Sometimes number_of_congruences erroneously returned 0 for
    the number of congruences with 1 class.
  * If an empty presentation (no generators or relations) was
    used to initialise short_rules, then the Sims1::for_each and
    Sims1::find_if could crash.
* Thu Sep 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.3.0
  * The "Sims1" class has been redesigned and improved to
    implement a parallel version of the low index congruences
    algorithm.
* Thu Sep 22 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.2.3
  * some unspecified minor fixes
* Mon Sep 12 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.2.2
  * some unspecified minor fixes
* Sat Aug 13 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.2.1
  * This is a minor release fixing a data race (probably) caused
    by setting the global locale
* Sat Jul  2 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.2.0
  * New: Sims Low-Index Congruence Algorithm
  * Added permutation group intersections
* Thu Apr 21 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.1.5
  * The Schreier-Sims object size function returned wrong results
* Fri Mar  4 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.1.4
  * Is is now possible to create the quotient_froidure_pin of a
    congruence with infinitely many classes.
  * Some exception messages were corrected for Bipartition
    objects.
* Thu Dec 16 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.1.3
  * Some performance improvements in ActionDigraph::number_of_paths,
    the suffix tree implementation, and in KnuthBendix.
* Tue Nov 30 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.1.2
  * New implementations of the linear time algorithm by Kambites
    for equality checking and the algorithm by Mitchell and
    Tsalakou for finding normal forms in small overlap monoids in
    the class `Kambites`.
  * A performance improvement in the implementation of Konieczny
    algorithm, for determining the structure of a finite
    semigroup or monoid.
  * An implementation of the linear time algorithm by Radoszewski
    and Rytter for checking equality of words in free bands in
    the function.
  * A major revision, expansion of the settings, and improvement
    in the performance of the implementation of the Todd-Coxeter
    algorithm in the class `ToddCoxeter`.
* Thu Nov 11 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.3
  * This release contains a minor change to the FroidurePin class
    template that resolves an issue with the python binding.
* Mon Sep 20 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.2
  * This release includes some missing operators, adapters, and
    docs were added.
* Sat Aug 28 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.1
  * konieczny: store lambda/rho positions for D class reps
* Wed May 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.0
  * Major rewrite of the functionality in libsemigroups for matrices,
    transformations, and other elements of semigroups. libsemigroups
    has been updated to use C++14 (from C++11), and some
    simplifications were made as a consequence. The documentation has
    been improved, some deprecated functionality was remove, and
    other minor improvements, and simplifications were made.
* Sun Feb 28 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.7
  * Fix a bug in `Konieczny`
  * Added a limit to `CongruenceByPairs`
* Fri Feb  5 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.6
  * This is a minor release for compatibility with the GAP
    package Semigroups.
* Thu Jan 28 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.5
  * Fix unspecified bug in ToddCoxeter
* Fri Nov 27 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.4
  * There were some bugs in the string formatting in exceptions
    on 32-bit systems.
  * The disjoint sets data structures were refactored completely,
    and their performance improved.
* Wed Oct  7 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.3
  * Build system changes only
* Fri Oct  2 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.2
  * Fixed: It was possible to create invalid `PBR` objects, which
    caused some incorrect values to be returned by
    `FroidurePin<PBR>` instances. The `to_string` implementation
    for `PBR` also did not work properly in all cases.
* Tue Sep 22 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.1
  * Support for disabling HPCombi (and thus AVX-256 requirement)
* Thu Sep 17 2020 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 0.6.7) for build.opensuse.org
